#%% begin initialize postgis-1.3.5-i586-P1
VER=1.3
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/lib/liblwgeom.so.$VER
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/lwpostgis.sql
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/lwpostgis_upgrade.sql
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/spatial_ref_sys.sql
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/topology.sql
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/lwpostgis_undef.sql
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/lwpostgis-uninstall.sh
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/share/contrib/lwpostgis-install.sh
/bin/chmod u+x $ROOT/./opt/pgsql/share/contrib/lwpostgis-install.sh
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/man/man1/pgsql2shp.1
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/man/man1/shp2pgsql.1
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/doc/postgis/postgis.html
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/doc/postgis/README.postgis

/bin/chown postgres.pgsql $ROOT/./opt/pgsql/bin/pgsql2shp
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/bin/shp2pgsql

( cd $ROOT/./opt/pgsql/lib ; rm -rf liblwgeom.so.1 )
( cd $ROOT/./opt/pgsql/lib ; ln -sf liblwgeom.so.$VER liblwgeom.so.1 )
( cd $ROOT/./opt/pgsql/lib ; rm -rf liblwgeom.so )
( cd $ROOT/./opt/pgsql/lib ; ln -sf liblwgeom.so.1 liblwgeom.so )
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/lib/liblwgeom.*
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/*
/bin/chown postgres.pgsql $ROOT/./opt/pgsql/.

A=`/bin/su - postgres -c "psql -t -c \"SELECT relname FROM pg_catalog.pg_class where relname = 'geometry_columns'\""`

if [ "$A" = "geometry_columns" ]; then
  /bin/su - postgres -c "$ROOT/./opt/pgsql/share/contrib/lwpostgis-upgrade.sh"
else
  /bin/su - postgres -c "$ROOT/./opt/pgsql/share/contrib/lwpostgis-install.sh"
fi
#%% end
